@@ -40,15 +40,11 @@ extern int compat_mode_24;
 #define HEX_OID_SIZE 25
 char *hex_oid_id;
 
-#if !MONGOC_CHECK_VERSION(1, 29, 0)
-#define bson_as_legacy_extended_json bson_as_json
-#endif
-
 #define dbg_bson(_prepend_txt, __bson_ptr__) \
 	do { \
 		char *__bson_str__; \
 		if (is_printable(L_DBG)) { \
-			__bson_str__ = bson_as_legacy_extended_json(__bson_ptr__, NULL); \
+			__bson_str__ = bson_as_json(__bson_ptr__, NULL); \
 			LM_DBG("%s%s\n", _prepend_txt, __bson_str__); \
 			bson_free(__bson_str__); \
 		} \
@@ -425,7 +421,10 @@ int mongo_raw_find(cachedb_con *con, bson_t *raw_query, bson_iter_t *ns,
 		v = bson_iter_value(&iter);
 		bson_init_static(&proj, v->value.v_doc.data, v->value.v_doc.data_len);
 #if MONGOC_CHECK_VERSION(1, 5, 0)
-		bson_append_document(opts, "projection", 10, &proj);
+		if (!bson_append_document(opts, "projection", 10, &proj)) {
+			LM_ERR("failed to append doc\n");
+			goto out_err;
+		}
 #else
 		fields = &proj;
 #endif
@@ -1310,11 +1309,11 @@ int mongo_db_query_trans(cachedb_con *con, const str *table, const db_key_t *_k,
 	                                   namespace);
 
 	if (is_printable(L_DBG)) {
-		strf = bson_as_legacy_extended_json(filter, NULL);
+		strf = bson_as_json(filter, NULL);
 #if MONGOC_CHECK_VERSION(1, 5, 0)
-		stro = bson_as_legacy_extended_json(opts, NULL);
+		stro = bson_as_json(opts, NULL);
 #else
-		stro = bson_as_legacy_extended_json(fields, NULL);
+		stro = bson_as_json(fields, NULL);
 #endif
 		LM_DBG("query doc:\n%s\n%s\n", strf, stro);
 		bson_free(strf);
@@ -1434,7 +1433,7 @@ int mongo_db_query_trans(cachedb_con *con, const str *table, const db_key_t *_k,
 						VAL_TYPE(cur_val) = DB_DATETIME;
 						VAL_TIME(cur_val) = bson_iter_date_time(&iter)/(int64_t)1000;
 						LM_DBG("Found time [%.*s]=[%d]\n",
-						       _c[c]->len, _c[c]->s, (int)VAL_TIME(cur_val));
+						       _c[c]->len, _c[c]->s, (int)(unsigned long)VAL_TIME(cur_val));
 						break;
 					case BSON_TYPE_OID:
 						bson_oid_to_string(bson_iter_oid(&iter), hex_oid);
